# pyDACP Authors
Below is a list of the contributors to pyDACP:

+ [Kostas Vilkelis](https://quantumtinkerer.tudelft.nl/members/kostas-vilkelis/)
+ [Antonio Manesco](https://antoniomanesco.org/)
+ [Anton Akhmerov](<https://antonakhmerov.org>)
+ [Michael Wimmer](https://michaelwimmer.org/)
